@@ -548,8 +548,8 @@ class SimultanObject(object, metaclass=MetaMock):
 
         # referenced components
         for comp in self._wrapped_obj.ReferencedComponents.Items:
-            c_slot = comp.ReferenceFunction.SlotBase.Base
-            c_slot_extension = comp.ReferenceFunction.SlotExtension
+            c_slot = comp.Slot.SlotBase.Base
+            c_slot_extension = comp.Slot.SlotExtension
 
             sc_df = sc_df.append(
                 pd.DataFrame(data={'comp': [self._template_parser.create_python_object(comp.Target)],
@@ -772,8 +772,8 @@ class SimultanObject(object, metaclass=MetaMock):
             # old component is reference
             elif self.slot_components.iloc[idx].comp_type == 1:
                 ref = next((x for x in self._wrapped_obj.ReferencedComponents.Items
-                            if ((x.ReferenceFunction.SlotBase.Base == slot_name) & (
-                        x.ReferenceFunction.SlotExtension == slot_extension))), None)
+                            if ((x.Slot.SlotBase.Base == slot_name) & (
+                        x.Slot.SlotExtension == slot_extension))), None)
                 if isinstance(new_component, SimultanObject):
                     new_sim_component = new_component._wrapped_obj
                     ref.Target = new_component._wrapped_obj
