@@ -544,7 +544,7 @@ class BaseGeometricFace(BaseGeoBaseClass):
         if self.construction_assignment.ReferencedComponents.Items.__len__() == 0:
             return
 
-        component = self.construction_assignment.ReferencedComponents.Items[0].Reference
+        component = self.construction_assignment.ReferencedComponents.Items[0].Target
         return self.geometry_model.template_parser.create_python_object(component, template_name='BuildInConstruction')
 
     @property
